@@ -11,7 +11,7 @@ from clouds.aws.aws_utils import set_and_verify_aws_credentials
 from simple_logger.logger import get_logger
 
 
-LOGGER = get_logger(__name__)
+LOGGER = get_logger(name=__name__)
 TIMEOUT_5MIN = 5 * 60
 
 
@@ -27,11 +27,20 @@ class NotLoggedInError(Exception):
     pass
 
 
-def hash_log_secrets(log, secrets):
-    for secret in secrets:
-        log = re.sub(
-            rf"(--{secret}=.* |--{secret}=.*)", f"--{secret}=hashed-{secret} ", log
-        )
+def hash_log_keys(log):
+    for _key in (
+        "token",
+        "worker-iam-role",
+        "support-role-arn",
+        "role-arn",
+        "controlplane-iam-role",
+        "kms-key-arn",
+        "etcd-encryption-kms-arn",
+        "audit-log-arn",
+        "base-domain",
+        "installer-role-arn",
+    ):
+        log = re.sub(rf"(--{_key}=[^\s]+)", f"--{_key}=hashed-value ", log)
 
     return log
 
@@ -66,9 +75,7 @@ def change_home_environment():
 def is_logged_in(aws_region=None, allowed_commands=None):
     _allowed_commands = allowed_commands or parse_help()
     try:
-        res = build_execute_command(
-            command="whoami", aws_region=aws_region, allowed_commands=_allowed_commands
-        )
+        res = build_execute_command(command="whoami", aws_region=aws_region, allowed_commands=_allowed_commands)
         return "User is not logged in to OCM" not in res["err"]
     except CommandExecuteError:
         return False
@@ -76,7 +83,7 @@ def is_logged_in(aws_region=None, allowed_commands=None):
 
 def execute_command(command, wait_timeout=TIMEOUT_5MIN):
     log = f"Executing command: {' '.join(command)}, waiting for {wait_timeout} seconds."
-    hashed_log = hash_log_secrets(log=log, secrets=["token"])
+    hashed_log = hash_log_keys(log=log)
     LOGGER.info(hashed_log)
     res = subprocess.run(command, capture_output=True, text=True, timeout=wait_timeout)
     if res.returncode != 0:
@@ -94,24 +101,18 @@ def check_flag_in_flags(command_list, flag_str):
 
 
 def build_command(command, allowed_commands=None, aws_region=None):
-    LOGGER.info(
-        hash_log_secrets(log=f"Parsing user command: {command}", secrets=["token"])
-    )
+    LOGGER.info(hash_log_keys(log=f"Parsing user command: {command}"))
     _allowed_commands = allowed_commands or parse_help()
     _user_command = shlex.split(command)
     command = ["rosa"]
     command.extend(_user_command)
-    commands_to_process = [
-        _cmd for _cmd in _user_command if not _cmd.startswith(("--", "-"))
-    ]
+    commands_to_process = [_cmd for _cmd in _user_command if not _cmd.startswith(("--", "-"))]
     commands_dict = benedict(_allowed_commands, keypath_separator=" ")
     commands_to_process_len = len(commands_to_process)
     extra_commands = set()
     for idx in range(commands_to_process_len):
         try:
-            _output = commands_dict[
-                commands_to_process[: commands_to_process_len - idx]
-            ]
+            _output = commands_dict[commands_to_process[: commands_to_process_len - idx]]
         except KeyError:
             continue
         if _output.get("json_output") is True:
@@ -134,9 +135,7 @@ def get_available_commands(command):
     __available_commands = []
     command.append("--help")
     res = subprocess.run(command, capture_output=True, check=True, text=True)
-    available_commands = re.findall(
-        r"Available Commands:(.*)\nFlags:", res.stdout, re.DOTALL
-    )
+    available_commands = re.findall(r"Available Commands:(.*)\nFlags:", res.stdout, re.DOTALL)
     if available_commands:
         available_commands = available_commands[0]
         available_commands = available_commands.strip()
@@ -150,12 +149,8 @@ def get_available_commands(command):
 
 def get_available_flags(command):
     command.append("--help")
-    available_flags = subprocess.run(
-        command, capture_output=True, check=True, text=True
-    )
-    available_flags = re.findall(
-        r"Flags:(.*)Global Flags:(.*)", available_flags.stdout, re.DOTALL
-    )
+    available_flags = subprocess.run(command, capture_output=True, check=True, text=True)
+    available_flags = re.findall(r"Flags:(.*)Global Flags:(.*)", available_flags.stdout, re.DOTALL)
     if available_flags:
         available_flags = " ".join([flags for flags in available_flags[0]])
         available_flags = available_flags.strip()
@@ -215,9 +210,7 @@ def parse_json_response(response):
 
 def build_execute_command(command, allowed_commands=None, aws_region=None):
     _allowed_commands = allowed_commands or parse_help()
-    command = build_command(
-        command=command, allowed_commands=_allowed_commands, aws_region=aws_region
-    )
+    command = build_command(command=command, allowed_commands=_allowed_commands, aws_region=aws_region)
     return execute_command(command=command)
 
 
@@ -284,13 +277,9 @@ def execute(
 
     else:
         if not is_logged_in(allowed_commands=_allowed_commands, aws_region=aws_region):
-            raise NotLoggedInError(
-                "Not logged in to OCM, either pass 'token' or log in before running."
-            )
+            raise NotLoggedInError("Not logged in to OCM, either pass 'token' or log in before running.")
 
-        return build_execute_command(
-            command=command, allowed_commands=_allowed_commands, aws_region=aws_region
-        )
+        return build_execute_command(command=command, allowed_commands=_allowed_commands, aws_region=aws_region)
 
 
 def _prepare_and_execute_command(allowed_commands, aws_region, command, ocm_env, token):
